/* Copyright (C) 2005, 2006, 2007, 2008, 2009 Stefan Frenz
 * 
 * This file is part of SJC, the Small Java Compiler written by Stefan Frenz.
 * 
 * SJC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * SJC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with SJC. If not, see <http://www.gnu.org/licenses/>.
 */

package frontend.sjava;

import compbase.*;
import backend.Architecture;
import backend.Instruction;

/**
 * StWhile: while- and do-while-loop
 * 
 * @author S. Frenz
 * @version 090207 added copyright notice
 *  version 080508 added flow hints
 *  version 070909 optimized signature of Expr.resolve, adopted changes in StBreakable
 *  version 070908 optimized signature of Stmt.resolve
 *  version 070114 reduced access level where possible
 *  version 070111 adapted change in printPos and compErr
 *  version 061229 removed access to firstInstr
 *  version 061203 optimized calls to printPos and compErr
 *  version 060607 initial version
 */

public class StWhile extends StBreakable {
	protected final static int W_EXCL = 1;
	protected final static int W_INCL = 2;
	
	protected Expr cond;
	protected Stmt loStmt;
	protected int whileType;
		
	protected StWhile(StBreakable io, StringList ila, int fid, int il, int ic) {
		super(io, ila, fid, il, ic);
	}
	
	protected boolean resolve(Unit unitContext, Mthd mthdContext, Context ctx) {
	  if (!cond.resolve(unitContext, mthdContext, ctx)) return false;
	  if (!loStmt.resolve(unitContext, mthdContext, ctx)) return false;
	  if (!cond.isBoolType()) {
	    printPos(ctx, "need boolean type in while-condition");
	    return false;
	  }
	  return true;
	}
	
	protected void genOutput(Context ctx) {
    Instruction loopDest;
    int id;
    
	  loopDest=ctx.arch.getUnlinkedInstruction();
    breakDest=ctx.arch.getUnlinkedInstruction();
    contDest=ctx.arch.getUnlinkedInstruction();
    id=ctx.arch.insertFlowHint(Architecture.F_BLOCKSTART, 0);
 	  if (whileType==W_EXCL) {
      if (cond.calcConstantType(ctx)==StdTypes.T_INT) {
        //condition is constant, reduce output
        if (cond.getConstIntValue(ctx)==0) return; //loop will never be executed
        //else: constant true, no check, just start the loop 
      }
      else ctx.arch.genJmp(contDest); //not constant, first check condition
    }
    ctx.arch.insertFlowHint(Architecture.F_LOOPSTART, id);
    ctx.arch.appendInstruction(loopDest);
	  loStmt.genOutput(ctx);
    ctx.arch.insertFlowHint(Architecture.F_CONDSTART, id);
    ctx.arch.appendInstruction(contDest);
	  cond.genOutputCondJmp(loopDest, true, breakDest, ctx);
	  ctx.arch.appendInstruction(breakDest);
    ctx.arch.insertFlowHint(Architecture.F_BLOCKEND, id);
    breakDest=contDest=null;
	}
}
