/* Copyright (C) 2005, 2006, 2007, 2008, 2009 Stefan Frenz
 * 
 * This file is part of SJC, the Small Java Compiler written by Stefan Frenz.
 * 
 * SJC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * SJC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with SJC. If not, see <http://www.gnu.org/licenses/>.
 */

package osio.sun;

import java.io.*;
import osio.DirLister;
import compbase.StringList;

/**
 * FileDirLister: list all files in a specific directory
 * 
 * @author S. Frenz
 * @version 090207 added copyright notice
 *  version 070727 fixed bug not clearing list on new listDir
 *  version 060808 added recurse-flag to avoid recursion on scan
 *  version 060613 adapted to osio-interfaces
 *  version 060607 initial version
 */

public class FileDirLister extends DirLister {
  private File start;
  private StringList result;
  
  public boolean initDir(String name) {
    result=null;
    start=new File(name);
    if (!start.isDirectory()) return false;
    return true;
  }
  
  public StringList listDir(boolean recurse) {
    appendDir(start, recurse);
    return result;
  }
  
  private void appendDir(File dir, boolean recurse) {
    File[] entries;
    StringList newFile;
    int i;
    
    entries=dir.listFiles();
    for (i=0; i<entries.length; i++) {
      if (entries[i].isDirectory()) {
        if (recurse) appendDir(entries[i], true);
      }
      else {
        try {
          newFile=new StringList(entries[i].getCanonicalPath());
          newFile.next=result;
          result=newFile;
        }
        catch (IOException e) {
          System.out.print("IO-error: "+e.getMessage());
        }
      }
    }
  }
}
