/* Copyright (C) 2006, 2007, 2008, 2009 Stefan Frenz
 * 
 * This file is part of SJC, the Small Java Compiler written by Stefan Frenz.
 * 
 * SJC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * SJC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with SJC. If not, see <http://www.gnu.org/licenses/>.
 */

package osio.sun;

import java.awt.*;
import javax.swing.*;
import emulation.TextScreen;

/**
 * GUIConsole: JComponent that looks like a 80x25 VGA text screen
 * 
 * @author S. Frenz
 * @version 090207 added copyright notice
 *  version 060612 added required Dimension-getter and updated colors
 *  version 060609 initial version
 */

public class GUIConsole extends JComponent implements TextScreen {
  public final static long serialVersionUID = 16047801002l;
  
  private final static byte F8x16[] = {
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7e, (byte)0x81, (byte)0xa5, (byte)0x81, (byte)0x81, (byte)0xbd,
    (byte)0x99, (byte)0x81, (byte)0x81, (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7e, (byte)0xff, (byte)0xdb, (byte)0xff, (byte)0xff, (byte)0xc3,
    (byte)0xe7, (byte)0xff, (byte)0xff, (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x6c, (byte)0xfe, (byte)0xfe, (byte)0xfe,
    (byte)0xfe, (byte)0x7c, (byte)0x38, (byte)0x10, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x7c, (byte)0xfe,
    (byte)0x7c, (byte)0x38, (byte)0x10, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3c, (byte)0x3c, (byte)0xe7, (byte)0xe7,
    (byte)0xe7, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3c, (byte)0x7e, (byte)0xff, (byte)0xff,
    (byte)0x7e, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3c,
    (byte)0x3c, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xe7, (byte)0xc3,
    (byte)0xc3, (byte)0xe7, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x66, (byte)0x42,
    (byte)0x42, (byte)0x66, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xc3, (byte)0x99, (byte)0xbd,
    (byte)0xbd, (byte)0x99, (byte)0xc3, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x1e, (byte)0x0e, (byte)0x1a, (byte)0x32, (byte)0x78, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x78, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x3c,
    (byte)0x18, (byte)0x7e, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3f, (byte)0x33, (byte)0x3f, (byte)0x30, (byte)0x30, (byte)0x30,
    (byte)0x30, (byte)0x70, (byte)0xf0, (byte)0xe0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7f, (byte)0x63, (byte)0x7f, (byte)0x63, (byte)0x63, (byte)0x63,
    (byte)0x63, (byte)0x67, (byte)0xe7, (byte)0xe6, (byte)0xc0, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0xdb, (byte)0x3c, (byte)0xe7,
    (byte)0x3c, (byte)0xdb, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x80, (byte)0xc0, (byte)0xe0, (byte)0xf0, (byte)0xf8, (byte)0xfe, (byte)0xf8,
    (byte)0xf0, (byte)0xe0, (byte)0xc0, (byte)0x80, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x02, (byte)0x06, (byte)0x0e, (byte)0x1e, (byte)0x3e, (byte)0xfe, (byte)0x3e,
    (byte)0x1e, (byte)0x0e, (byte)0x06, (byte)0x02, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3c, (byte)0x7e, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x7e, (byte)0x3c, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66,
    (byte)0x66, (byte)0x00, (byte)0x66, (byte)0x66, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7f, (byte)0xdb, (byte)0xdb, (byte)0xdb, (byte)0x7b, (byte)0x1b,
    (byte)0x1b, (byte)0x1b, (byte)0x1b, (byte)0x1b, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0x60, (byte)0x38, (byte)0x6c, (byte)0xc6, (byte)0xc6,
    (byte)0x6c, (byte)0x38, (byte)0x0c, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0xfe, (byte)0xfe, (byte)0xfe, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3c, (byte)0x7e, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x7e, (byte)0x3c, (byte)0x18, (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3c, (byte)0x7e, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x7e, (byte)0x3c, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x0c, (byte)0xfe,
    (byte)0x0c, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x30, (byte)0x60, (byte)0xfe,
    (byte)0x60, (byte)0x30, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xc0, (byte)0xc0,
    (byte)0xc0, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x24, (byte)0x66, (byte)0xff,
    (byte)0x66, (byte)0x24, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x38, (byte)0x7c,
    (byte)0x7c, (byte)0xfe, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0xfe, (byte)0x7c, (byte)0x7c,
    (byte)0x38, (byte)0x38, (byte)0x10, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3c, (byte)0x3c, (byte)0x3c, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x24, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x6c, (byte)0x6c, (byte)0xfe, (byte)0x6c, (byte)0x6c,
    (byte)0x6c, (byte)0xfe, (byte)0x6c, (byte)0x6c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x18, (byte)0x18, (byte)0x7c, (byte)0xc6, (byte)0xc2, (byte)0xc0, (byte)0x7c, (byte)0x06,
    (byte)0x06, (byte)0x86, (byte)0xc6, (byte)0x7c, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xc2, (byte)0xc6, (byte)0x0c, (byte)0x18,
    (byte)0x30, (byte)0x60, (byte)0xc6, (byte)0x86, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0x6c, (byte)0x38, (byte)0x76, (byte)0xdc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x60, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x0c, (byte)0x18, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30,
    (byte)0x30, (byte)0x30, (byte)0x18, (byte)0x0c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x30, (byte)0x18, (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x0c,
    (byte)0x0c, (byte)0x0c, (byte)0x18, (byte)0x30, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x66, (byte)0x3c, (byte)0xff,
    (byte)0x3c, (byte)0x66, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x7e,
    (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x30, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x02, (byte)0x06, (byte)0x0c, (byte)0x18,
    (byte)0x30, (byte)0x60, (byte)0xc0, (byte)0x80, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x66, (byte)0xc3, (byte)0xc3, (byte)0xdb, (byte)0xdb,
    (byte)0xc3, (byte)0xc3, (byte)0x66, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x38, (byte)0x78, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0x06, (byte)0x0c, (byte)0x18, (byte)0x30,
    (byte)0x60, (byte)0xc0, (byte)0xc6, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0x06, (byte)0x06, (byte)0x3c, (byte)0x06,
    (byte)0x06, (byte)0x06, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x0c, (byte)0x1c, (byte)0x3c, (byte)0x6c, (byte)0xcc, (byte)0xfe,
    (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x1e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0xc0, (byte)0xc0, (byte)0xc0, (byte)0xfc, (byte)0x06,
    (byte)0x06, (byte)0x06, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x38, (byte)0x60, (byte)0xc0, (byte)0xc0, (byte)0xfc, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0xc6, (byte)0x06, (byte)0x06, (byte)0x0c, (byte)0x18,
    (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7e, (byte)0x06,
    (byte)0x06, (byte)0x06, (byte)0x0c, (byte)0x78, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x30, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x06, (byte)0x0c, (byte)0x18, (byte)0x30, (byte)0x60,
    (byte)0x30, (byte)0x18, (byte)0x0c, (byte)0x06, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7e, (byte)0x00, (byte)0x00,
    (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x0c, (byte)0x06,
    (byte)0x0c, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0x0c, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0xde, (byte)0xde,
    (byte)0xde, (byte)0xdc, (byte)0xc0, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x6c, (byte)0xc6, (byte)0xc6, (byte)0xfe,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xfc, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x7c, (byte)0x66,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0xfc, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x66, (byte)0xc2, (byte)0xc0, (byte)0xc0, (byte)0xc0,
    (byte)0xc0, (byte)0xc2, (byte)0x66, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xf8, (byte)0x6c, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66,
    (byte)0x66, (byte)0x66, (byte)0x6c, (byte)0xf8, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0x66, (byte)0x62, (byte)0x68, (byte)0x78, (byte)0x68,
    (byte)0x60, (byte)0x62, (byte)0x66, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0x66, (byte)0x62, (byte)0x68, (byte)0x78, (byte)0x68,
    (byte)0x60, (byte)0x60, (byte)0x60, (byte)0xf0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x66, (byte)0xc2, (byte)0xc0, (byte)0xc0, (byte)0xde,
    (byte)0xc6, (byte)0xc6, (byte)0x66, (byte)0x3a, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xfe, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x1e, (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x0c,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x78, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xe6, (byte)0x66, (byte)0x66, (byte)0x6c, (byte)0x78, (byte)0x78,
    (byte)0x6c, (byte)0x66, (byte)0x66, (byte)0xe6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xf0, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x60,
    (byte)0x60, (byte)0x62, (byte)0x66, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0xe7, (byte)0xff, (byte)0xff, (byte)0xdb, (byte)0xc3,
    (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc6, (byte)0xe6, (byte)0xf6, (byte)0xfe, (byte)0xde, (byte)0xce,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xfc, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x7c, (byte)0x60,
    (byte)0x60, (byte)0x60, (byte)0x60, (byte)0xf0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xd6, (byte)0xde, (byte)0x7c, (byte)0x0c, (byte)0x0e, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xfc, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x7c, (byte)0x6c,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0xe6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0x60, (byte)0x38, (byte)0x0c,
    (byte)0x06, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xff, (byte)0xdb, (byte)0x99, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0xc3,
    (byte)0xc3, (byte)0x66, (byte)0x3c, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0xdb,
    (byte)0xdb, (byte)0xff, (byte)0x66, (byte)0x66, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0xc3, (byte)0x66, (byte)0x3c, (byte)0x18, (byte)0x18,
    (byte)0x3c, (byte)0x66, (byte)0xc3, (byte)0xc3, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0xc3, (byte)0xc3, (byte)0x66, (byte)0x3c, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xff, (byte)0xc3, (byte)0x86, (byte)0x0c, (byte)0x18, (byte)0x30,
    (byte)0x60, (byte)0xc1, (byte)0xc3, (byte)0xff, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30,
    (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x80, (byte)0xc0, (byte)0xe0, (byte)0x70, (byte)0x38,
    (byte)0x1c, (byte)0x0e, (byte)0x06, (byte)0x02, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x0c,
    (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x10, (byte)0x38, (byte)0x6c, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xff, (byte)0x00, (byte)0x00,
    (byte)0x30, (byte)0x30, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x78, (byte)0x0c, (byte)0x7c,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xe0, (byte)0x60, (byte)0x60, (byte)0x78, (byte)0x6c, (byte)0x66,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc0,
    (byte)0xc0, (byte)0xc0, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x1c, (byte)0x0c, (byte)0x0c, (byte)0x3c, (byte)0x6c, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xfe,
    (byte)0xc0, (byte)0xc0, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0x64, (byte)0x60, (byte)0xf0, (byte)0x60,
    (byte)0x60, (byte)0x60, (byte)0x60, (byte)0xf0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x76, (byte)0xcc, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x7c, (byte)0x0c, (byte)0xcc, (byte)0x78, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xe0, (byte)0x60, (byte)0x60, (byte)0x6c, (byte)0x76, (byte)0x66,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0xe6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x38, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x06, (byte)0x06, (byte)0x00, (byte)0x0e, (byte)0x06, (byte)0x06,
    (byte)0x06, (byte)0x06, (byte)0x06, (byte)0x06, (byte)0x66, (byte)0x66, (byte)0x3c, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xe0, (byte)0x60, (byte)0x60, (byte)0x66, (byte)0x6c, (byte)0x78,
    (byte)0x78, (byte)0x6c, (byte)0x66, (byte)0xe6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x38, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xe6, (byte)0xff, (byte)0xdb,
    (byte)0xdb, (byte)0xdb, (byte)0xdb, (byte)0xdb, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xdc, (byte)0x66, (byte)0x66,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xdc, (byte)0x66, (byte)0x66,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x7c, (byte)0x60, (byte)0x60, (byte)0xf0, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x76, (byte)0xcc, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x7c, (byte)0x0c, (byte)0x0c, (byte)0x1e, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xdc, (byte)0x76, (byte)0x66,
    (byte)0x60, (byte)0x60, (byte)0x60, (byte)0xf0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0x60,
    (byte)0x38, (byte)0x0c, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x30, (byte)0x30, (byte)0xfc, (byte)0x30, (byte)0x30,
    (byte)0x30, (byte)0x30, (byte)0x36, (byte)0x1c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xcc, (byte)0xcc, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0xc3, (byte)0xc3,
    (byte)0xc3, (byte)0x66, (byte)0x3c, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0xc3, (byte)0xc3,
    (byte)0xdb, (byte)0xdb, (byte)0xff, (byte)0x66, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0x66, (byte)0x3c,
    (byte)0x18, (byte)0x3c, (byte)0x66, (byte)0xc3, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xc6, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7e, (byte)0x06, (byte)0x0c, (byte)0xf8, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0xcc, (byte)0x18,
    (byte)0x30, (byte)0x60, (byte)0xc6, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x0e, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x70, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x0e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x70, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x0e, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x70, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x76, (byte)0xdc, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x6c, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x66, (byte)0xc2, (byte)0xc0, (byte)0xc0, (byte)0xc0,
    (byte)0xc2, (byte)0x66, (byte)0x3c, (byte)0x0c, (byte)0x06, (byte)0x7c, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xcc, (byte)0x00, (byte)0x00, (byte)0xcc, (byte)0xcc, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x0c, (byte)0x18, (byte)0x30, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xfe,
    (byte)0xc0, (byte)0xc0, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x6c, (byte)0x00, (byte)0x78, (byte)0x0c, (byte)0x7c,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xcc, (byte)0x00, (byte)0x00, (byte)0x78, (byte)0x0c, (byte)0x7c,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x00, (byte)0x78, (byte)0x0c, (byte)0x7c,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0x38, (byte)0x00, (byte)0x78, (byte)0x0c, (byte)0x7c,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x3c, (byte)0x66, (byte)0x60, (byte)0x60,
    (byte)0x66, (byte)0x3c, (byte)0x0c, (byte)0x06, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x6c, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xfe,
    (byte)0xc0, (byte)0xc0, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xfe,
    (byte)0xc0, (byte)0xc0, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xfe,
    (byte)0xc0, (byte)0xc0, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x66, (byte)0x00, (byte)0x00, (byte)0x38, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x18, (byte)0x3c, (byte)0x66, (byte)0x00, (byte)0x38, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x00, (byte)0x38, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0xc6, (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x6c, (byte)0xc6, (byte)0xc6,
    (byte)0xfe, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x38, (byte)0x6c, (byte)0x38, (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0xc6, (byte)0xc6,
    (byte)0xfe, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x00, (byte)0xfe, (byte)0x66, (byte)0x60, (byte)0x7c,
    (byte)0x60, (byte)0x60, (byte)0x66, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x6e, (byte)0x3b, (byte)0x1b,
    (byte)0x7e, (byte)0xd8, (byte)0xdc, (byte)0x77, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x3e, (byte)0x6c, (byte)0xcc, (byte)0xcc, (byte)0xfe, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0xce, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x6c, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x30, (byte)0x78, (byte)0xcc, (byte)0x00, (byte)0xcc, (byte)0xcc, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x00, (byte)0xcc, (byte)0xcc, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0xc6, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7e, (byte)0x06, (byte)0x0c, (byte)0x78, (byte)0x00,
    (byte)0x00, (byte)0xc6, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0xc6, (byte)0x00, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x7e, (byte)0xc3, (byte)0xc0, (byte)0xc0, (byte)0xc0,
    (byte)0xc3, (byte)0x7e, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0x64, (byte)0x60, (byte)0xf0, (byte)0x60, (byte)0x60,
    (byte)0x60, (byte)0x60, (byte)0xe6, (byte)0xfc, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xc3, (byte)0x66, (byte)0x3c, (byte)0x18, (byte)0xff, (byte)0x18,
    (byte)0xff, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0xfc, (byte)0x66, (byte)0x66, (byte)0x7c, (byte)0x62, (byte)0x66, (byte)0x6f,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0xf3, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x0e, (byte)0x1b, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x7e, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xd8, (byte)0x70, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x00, (byte)0x78, (byte)0x0c, (byte)0x7c,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x0c, (byte)0x18, (byte)0x30, (byte)0x00, (byte)0x38, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x00, (byte)0xcc, (byte)0xcc, (byte)0xcc,
    (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x76, (byte)0xdc, (byte)0x00, (byte)0xdc, (byte)0x66, (byte)0x66,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x76, (byte)0xdc, (byte)0x00, (byte)0xc6, (byte)0xe6, (byte)0xf6, (byte)0xfe, (byte)0xde,
    (byte)0xce, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x3c, (byte)0x6c, (byte)0x6c, (byte)0x3e, (byte)0x00, (byte)0x7e, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0x6c, (byte)0x38, (byte)0x00, (byte)0x7c, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x60,
    (byte)0xc0, (byte)0xc6, (byte)0xc6, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0xc0,
    (byte)0xc0, (byte)0xc0, (byte)0xc0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0x06,
    (byte)0x06, (byte)0x06, (byte)0x06, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0xc0, (byte)0xc0, (byte)0xc2, (byte)0xc6, (byte)0xcc, (byte)0x18, (byte)0x30,
    (byte)0x60, (byte)0xce, (byte)0x9b, (byte)0x06, (byte)0x0c, (byte)0x1f, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0xc0, (byte)0xc0, (byte)0xc2, (byte)0xc6, (byte)0xcc, (byte)0x18, (byte)0x30,
    (byte)0x66, (byte)0xce, (byte)0x96, (byte)0x3e, (byte)0x06, (byte)0x06, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x3c, (byte)0x3c, (byte)0x3c, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x36, (byte)0x6c, (byte)0xd8,
    (byte)0x6c, (byte)0x36, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xd8, (byte)0x6c, (byte)0x36,
    (byte)0x6c, (byte)0xd8, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x11, (byte)0x44, (byte)0x11, (byte)0x44, (byte)0x11, (byte)0x44, (byte)0x11, (byte)0x44,
    (byte)0x11, (byte)0x44, (byte)0x11, (byte)0x44, (byte)0x11, (byte)0x44, (byte)0x11, (byte)0x44,
    (byte)0x55, (byte)0xaa, (byte)0x55, (byte)0xaa, (byte)0x55, (byte)0xaa, (byte)0x55, (byte)0xaa,
    (byte)0x55, (byte)0xaa, (byte)0x55, (byte)0xaa, (byte)0x55, (byte)0xaa, (byte)0x55, (byte)0xaa,
    (byte)0xdd, (byte)0x77, (byte)0xdd, (byte)0x77, (byte)0xdd, (byte)0x77, (byte)0xdd, (byte)0x77,
    (byte)0xdd, (byte)0x77, (byte)0xdd, (byte)0x77, (byte)0xdd, (byte)0x77, (byte)0xdd, (byte)0x77,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xf8,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xf8, (byte)0x18, (byte)0xf8,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xf6,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xf8, (byte)0x18, (byte)0xf8,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xf6, (byte)0x06, (byte)0xf6,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0x06, (byte)0xf6,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xf6, (byte)0x06, (byte)0xfe,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xfe,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xf8, (byte)0x18, (byte)0xf8,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xf8,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x1f,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xff,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x1f,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xff,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x1f, (byte)0x18, (byte)0x1f,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x37,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x37, (byte)0x30, (byte)0x3f,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x3f, (byte)0x30, (byte)0x37,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xf7, (byte)0x00, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xff, (byte)0x00, (byte)0xf7,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x37, (byte)0x30, (byte)0x37,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xff, (byte)0x00, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xf7, (byte)0x00, (byte)0xf7,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xff, (byte)0x00, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xff, (byte)0x00, (byte)0xff,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xff,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x3f,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x1f, (byte)0x18, (byte)0x1f,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x1f, (byte)0x18, (byte)0x1f,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x3f,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xff,
    (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xff, (byte)0x18, (byte)0xff,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xf8,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x1f,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff,
    (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xff,
    (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff,
    (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0,
    (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0, (byte)0xf0,
    (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f,
    (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f, (byte)0x0f,
    (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0xff, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x76, (byte)0xdc, (byte)0xd8,
    (byte)0xd8, (byte)0xd8, (byte)0xdc, (byte)0x76, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x78, (byte)0xcc, (byte)0xcc, (byte)0xcc, (byte)0xd8, (byte)0xcc,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xcc, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0xc6, (byte)0xc6, (byte)0xc0, (byte)0xc0, (byte)0xc0,
    (byte)0xc0, (byte)0xc0, (byte)0xc0, (byte)0xc0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0x6c, (byte)0x6c, (byte)0x6c,
    (byte)0x6c, (byte)0x6c, (byte)0x6c, (byte)0x6c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0xc6, (byte)0x60, (byte)0x30, (byte)0x18,
    (byte)0x30, (byte)0x60, (byte)0xc6, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7e, (byte)0xd8, (byte)0xd8,
    (byte)0xd8, (byte)0xd8, (byte)0xd8, (byte)0x70, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66,
    (byte)0x66, (byte)0x7c, (byte)0x60, (byte)0x60, (byte)0xc0, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x76, (byte)0xdc, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7e, (byte)0x18, (byte)0x3c, (byte)0x66, (byte)0x66,
    (byte)0x66, (byte)0x3c, (byte)0x18, (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0xc6, (byte)0xc6, (byte)0xfe,
    (byte)0xc6, (byte)0xc6, (byte)0x6c, (byte)0x38, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x6c,
    (byte)0x6c, (byte)0x6c, (byte)0x6c, (byte)0xee, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x1e, (byte)0x30, (byte)0x18, (byte)0x0c, (byte)0x3e, (byte)0x66,
    (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x3c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7e, (byte)0xdb, (byte)0xdb,
    (byte)0xdb, (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x03, (byte)0x06, (byte)0x7e, (byte)0xdb, (byte)0xdb,
    (byte)0xf3, (byte)0x7e, (byte)0x60, (byte)0xc0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x1c, (byte)0x30, (byte)0x60, (byte)0x60, (byte)0x7c, (byte)0x60,
    (byte)0x60, (byte)0x60, (byte)0x30, (byte)0x1c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6,
    (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0xc6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0xfe,
    (byte)0x00, (byte)0x00, (byte)0xfe, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x7e, (byte)0x18,
    (byte)0x18, (byte)0x00, (byte)0x00, (byte)0xff, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x30, (byte)0x18, (byte)0x0c, (byte)0x06, (byte)0x0c,
    (byte)0x18, (byte)0x30, (byte)0x00, (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x0c, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x30,
    (byte)0x18, (byte)0x0c, (byte)0x00, (byte)0x7e, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x0e, (byte)0x1b, (byte)0x1b, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18,
    (byte)0xd8, (byte)0xd8, (byte)0xd8, (byte)0x70, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x7e,
    (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x76, (byte)0xdc, (byte)0x00,
    (byte)0x76, (byte)0xdc, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x38, (byte)0x6c, (byte)0x6c, (byte)0x38, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18,
    (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x0f, (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0x0c, (byte)0xec,
    (byte)0x6c, (byte)0x6c, (byte)0x3c, (byte)0x1c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0xd8, (byte)0x6c, (byte)0x6c, (byte)0x6c, (byte)0x6c, (byte)0x6c, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x70, (byte)0xd8, (byte)0x30, (byte)0x60, (byte)0xc8, (byte)0xf8, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7c, (byte)0x7c, (byte)0x7c, (byte)0x7c,
    (byte)0x7c, (byte)0x7c, (byte)0x7c, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00,
    (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00};
  
  private final static int charWidth=8, charHeight=16;
  
  private int col, row;
  private char[][] txt;
  private int[][] colFG, colBG;
  private Color[] colTable;
  
  private Image backImage;
  
  public GUIConsole(int iw, int ih) {
    super();
    
    int x, y;
    
    txt=new char[ih][iw];
    colFG=new int[ih][iw];
    colBG=new int[ih][iw];
    for (y=0; y<ih; y++) for (x=0; x<iw; x++) {
      txt[y][x]=' ';
      colFG[y][x]=7; //colBG is initialized to 0
    }
    colTable=new Color[16];
    colTable[0]=new Color(0x000000); //black
    colTable[1]=new Color(0x00007F); //blue
    colTable[2]=new Color(0x007F00); //green
    colTable[3]=new Color(0x007F7F); //cyan
    colTable[4]=new Color(0x7F0000); //red
    colTable[5]=new Color(0x7F007F); //magenta
    colTable[6]=new Color(0x7F7F00); //brown
    colTable[7]=new Color(0x7F7F7F); //white
    colTable[8]=new Color(0x4F4F4F); //gray
    colTable[9]=new Color(0x0000FF); //bright blue
    colTable[10]=new Color(0x00FF00); //bright green
    colTable[11]=new Color(0x00FFFF); //bright cyan
    colTable[12]=new Color(0xFF0000); //bright red
    colTable[13]=new Color(0xFF00FF); //bright magenta
    colTable[14]=new Color(0xFFFF00); //bright yellow
    colTable[15]=new Color(0xFFFFFF); //bright white
    col=iw;
    row=ih;
    setSize(charWidth*col, charHeight*row);
  }
  
  public void setChar(int x, int y, char c) {
    txt[y][x]=c;
  }
  
  public void setColor(int x, int y, byte col) {
    colFG[y][x]=(int)col&0x0F;
    colBG[y][x]=((int)col&0xF0)>>>4;
  }
  
  public int getWidth() {
    return charWidth*col;
  }
  
  public int getHeight() {
    return charHeight*row;
  }
  
  public Dimension getPreferredSize() {
    return new Dimension(getWidth(), getHeight());
  }
  
  public void redraw() {
    if (backImage!=null) {
      redraw(backImage.getGraphics());
      repaint();
    }
  }
  
  public void redraw(int x, int y) {
    if (backImage!=null) {
      drawChar(backImage.getGraphics(), x, y);
      repaint();
    }
  }
  
  public void paint(Graphics g) {
    Dimension size;
    
    if (backImage==null) {
      size=super.getSize();
      backImage=createImage(size.width, size.height);
      redraw();
    }
    g.drawImage(backImage, 0, 0, this);
  }
  
  private void redraw(Graphics g) {
    for (int y=0; y<row; y++) for (int x=0; x<col; x++) drawChar(g, x, y);
  }
  
  private void drawChar(Graphics g, int x, int y) {
    int sx=x*charWidth, sy=y*charHeight, base;
    
    base=((int)txt[y][x]&0xFF)*charHeight;
    for (int j=0; j<charHeight; j++) {
      for (int i=0; i<charWidth; i++) {
        if ((F8x16[base]&(1<<(7-i)))!=0) g.setColor(colTable[colFG[y][x]]);
        else g.setColor(colTable[colBG[y][x]]);
        g.drawLine(sx+i, sy+j, sx+i, sy+j);
      }
      base++;
    }
  }
}
