/* Copyright (C) 2005, 2006, 2007, 2008, 2009 Stefan Frenz
 * 
 * This file is part of SJC, the Small Java Compiler written by Stefan Frenz.
 * 
 * SJC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * SJC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with SJC. If not, see <http://www.gnu.org/licenses/>.
 */

package output;

import memory.ImageContainer;
import osio.TextPrinter;
import compbase.CommBase;

/**
 * RawOut: just write the created image
 * 
 * @author S. Frenz
 * @version 090207 added copyright notice
 *  version 070105 removed prefixing
 *  version 060818 adapted changed interface
 *  version 060607 initial version
 */

public class RawOut extends OutputFormat {
  private String prefix;
  
  public static void printValidParameters(TextPrinter v) {
    v.println("   --- no parameter required");
  }
  
  public boolean setParameter(String parm, TextPrinter v) {
    v.println("No parameter expected for RawOut");
    return false;
  }
  
  public boolean checkParameter(CommBase comm) {
    //nothing to check
    return true;
  }
  
  public boolean writeOutput(CommBase comm, ImageContainer img, ImageContainer cimg, int cilen) {
    boolean res;
    String name;
    
    name="raw_out.bin";
    if (prefix!=null) name=prefix.concat(name);
    
    if (!comm.outBin.open(name)) {
      comm.out.print("Error opening output-file ");
      comm.out.println(name);
      return false;
    }
    res=img.appendImage(comm.outBin);
    comm.outBin.close();
    return res;
  }
}
