/* Copyright (C) 2006, 2007, 2008, 2009 Stefan Frenz
 * 
 * This file is part of SJC, the Small Java Compiler written by Stefan Frenz.
 * 
 * SJC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * SJC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with SJC. If not, see <http://www.gnu.org/licenses/>.
 */

package ui;

import memory.BootableImage;
import osio.BinWriter;
import osio.sun.*;
import output.BootOut;
import compbase.CommBase;

/**
 * Boot: make a raw_out-file bootable
 * 
 * @author S. Frenz
 * @version 090207 added copyright notice
 *  version 080712 adopted changed compile-interface
 *  version 060818 adapted changed interface of OutputFormat
 *  version 060817 added version history
 */

public class Boot {
  private static class RawContainer extends BootableImage {
    public boolean init(byte[] data) {
      if ((memBlock=data)==null) return false; //get binary data
      baseAddress=readInt(0); //get baseAddress
      if ((memBlockLen=memBlock.length)!=readInt(4)) return false; //get and check length
      if ((readInt(28)&0xFF0000FF)!=0x550000AA) return false; //check endianess
      return true;
    }
    
    public int getStartUnit() { return readInt(8); }
    public int getStartCode() { return readInt(12); }
    
    public boolean appendImage(BinWriter w) {
      return w.write(memBlock, 0, memBlockLen);
    }

    private int readInt(int off) {
      return ((int)memBlock[off]&0xFF)|(((int)memBlock[off+1]&0xFF)<<8)
        |(((int)memBlock[off+2]&0xFF)<<16)|(((int)memBlock[off+3]&0xFF)<<24);
    }
  }
  
  public static void main(String[] args) {
    CommBase comm;
    RawContainer img;
    BootOut bo;
    
    comm=new CommBase(new StreamTextPrinter(), new FileBinWriter(),
        new FileTextReader(), new FileBinReader());
    if (!(img=new RawContainer()).init(comm.inBin.readFile("raw_out.bin"))) {
      comm.out.println("error initializing from raw image");
      return;
    }
    bo=new BootOut();
    if (args!=null) for (int i=0; i<args.length; i++) bo.setParameter(args[i], comm.out);
    bo.checkParameter(comm);
    bo.writeOutput(comm, img, null, 0);
  }
}
